#
# spec file for package apache2-mod_security2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           apache2-mod_security2
Version:        2.9.8
Release:        3.1
Summary:        Web Application Firewall for Apache httpd
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://www.modsecurity.org/
Source0:        https://github.com/owasp-modsecurity/ModSecurity/releases/download/v%{version}/modsecurity-v%{version}.tar.gz
Source1:        https://github.com/owasp-modsecurity/ModSecurity/releases/download/v%{version}/modsecurity-v%{version}.tar.gz.asc
Source2:        apache2-mod_security2.keyring
Source3:        mod_security2.conf
Source4:        README_SUSE
Patch0:         apache2-mod_security2-no_rpath.diff
Patch1:         modsecurity-fixes.patch
Patch2:         apache2-mod_security2_tests_conf.patch
# https://github.com/SpiderLabs/ModSecurity/issues/2514
Patch3:         modsecurity-2.9.3-input_filtering_errors.patch
# fix build with gcc14
Patch4:         apache2-mod_security2-gcc14.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  apache2-prefork
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  c++_compiler
BuildRequires:  libcurl-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  lua53-devel
BuildRequires:  pcre2-devel
BuildRequires:  perl-libwww-perl
BuildRequires:  pkgconfig
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
Recommends:     owasp-modsecurity-crs-apache2

%description
ModSecurity is an intrusion detection and prevention
engine for web applications (or a web application firewall). Operating
as an Apache Web server module or standalone, the purpose of
ModSecurity is to increase web application security, protecting web
applications from known and unknown attacks.

%prep
%autosetup -p1 -n modsecurity-v%{version}
cp %{SOURCE4} .

%build
aclocal
automake
%configure \
	--with-apxs=%{apache_apxs} \
	--enable-request-early \
	--enable-htaccess-config \
	--disable-mlogc \
	--with-pcre2 \
	%{nil}
%make_build

%install
pushd apache2
  install -d -m 0755 %{buildroot}%{apache_libexecdir}
  install .libs/mod_security2.so %{buildroot}%{apache_libexecdir}/mod_security2.so
popd
mkdir -p %{buildroot}%{apache_sysconfdir}/mod_security2.d
mkdir -p %{buildroot}%{apache_sysconfdir}/mod_security2.d/rules
mkdir -p %{buildroot}%{apache_sysconfdir}/conf.d/
cp -a %{SOURCE3} %{buildroot}%{apache_sysconfdir}/conf.d/

%files
%{apache_libexecdir}/mod_security2.so
%license LICENSE
%dir %{apache_sysconfdir}/mod_security2.d
%dir %{apache_sysconfdir}/mod_security2.d/rules
%dir %{apache_sysconfdir}/conf.d/
%config(noreplace) %{apache_sysconfdir}/conf.d/mod_security2.conf
%doc README.md CHANGES NOTICE authors.txt README_SUSE

%changelog
* Fri Mar 14 2025 Andreas Stieger <andreas.stieger@gmx.de>
- build with pcre2 (test suite disabled temporarily)
* Tue Jan 21 2025 pgajdos@suse.com
- package cleanup, coordinated with owasp-modsecurity-crs cleanup
- version update to 2.9.8 (changed upstream: Trustwave -> OWASP)
  * Fixed ap_log_perror() usage
  * Memory leaks + enhanced logging
  * CI improvement: First check syntax & always display error/audit logs
  * Fixed assert() usage
  * Removed useless code
  * feat: Check if the MP header contains invalid character
  * Use standard httpd logging format in error log
  * fix msc_regexec() != PCRE_ERROR_NOMATCH strict check
  * Move xmlFree() call to the right place
  * Add collection size in log in case of writing error
  * Passing address of lock instead of lock in acquire_global_lock()
  * Invalid pointer access in case rule id == NOT_SET_P
  * Show error.log after httpd start in CI
  * chore: add pull request template
  * chore: add gitignore file
  * Possible double free
  * Set 'jit' variable's initial value
  * Missing null byte + optimization
  * fix: remove usage of insecure tmpname
  * docs: update copyright
  * Enhanced logging [Issue #3107]
  * Check for null pointer dereference (almost) everywhere
  * Fix possible segfault in collection_unpack
  * fix: Replace obsolete macros
  * chore: update bug-report-for-version-2-x.md
  * feat: Add more steps: install built module and restart the server
  * Add new flag: --without-lua
  * Initial release of CI worklow
  * V2/fixbuildissue
  * ; incorrectly replaced by space in cmdline
  * Detailed error message when writing collections
  * docs: Fix organization name in references and security e-mail (v2)
  * ctl:ruleRemoveByTag isn't executed if no rule id is present in the rule
  * Suppress useless loop on tag matching
  * Optimization: Avoid last loop and storing an empty value in case nothing
    after last %%{..} macro
  * Ignore (consistently) empty actions
  * Add context info to error message
  * Implement msre_action_phase_validate()
  * Avoid some useless code and memory allocation in case no macro is present
  * 'jit' variable not initialized when WITH_PCRE2 is defined
  * Configure: do not check for pcre1 if pcre2 requested
  * Double memory allocation
  * Fix for DEBUG_CONF compile flag
  * Enhance logging
  * Fix possible segfault in collection_unpack
  * Set the minimum security protocol version for SecRemoteRules
  * Allow lua version 5.4
  * Configure: do not check for pcre1 if pcre2 requested
  * Check return code of apr_procattr_io_set()
  * Do not escape special chars in rx pattern with macro
  * Substitute two equals-equals operators in build
- modified patches
  %% apache2-mod_security2-no_rpath.diff (refreshed)
  %% modsecurity-2.9.3-input_filtering_errors.patch (refreshed)
  %% modsecurity-fixes.patch (refreshed)
- added sources
  + apache2-mod_security2.keyring
* Tue Jun  4 2024 pgajdos@suse.com
- %%autopatch instead of %%patchN
- modified patches
  %% apache2-mod_security2-no_rpath.diff (refreshed)
* Tue Jun  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix patch application syntax: Use %%patch -P N instead of
  deprecated %%patchN.
* Tue May  7 2024 pgajdos@suse.com
- added patches
  fix fix build with gcc14
  + apache2-mod_security2-gcc14.patch
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jul 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9.7:
  * Fix: FILES_TMP_CONTENT may sometimes lack complete content
  * Support configurable limit on number of arguments processed
  * Silence compiler warning about discarded const
  * Support for JIT option for PCRE2
  * Use uid for user if apr_uid_name_get() fails
  * Fix: handle error with SecConnReadStateLimit configuration
  * Only check for pcre2 install if required
  * Adjustment of previous fix for log messages
  * Mark apache error log messages as from mod_security2
  * Use pkg-config to find libxml2 first
  * Support for PCRE2 in mlogc
  * Support for PCRE2
  * Adjust parser activation rules in modsecurity.conf-
    recommended
  * Multipart parsing fixes and new MULTIPART_PART_HEADERS
    collection
  * Limit rsub null termination to where necessary
  * IIS: Update dependencies for next planned release
  * XML parser cleanup: NULL duplicate pointer
  * Properly cleanup XML parser contexts upon completion
  * Fix memory leak in streams
  * Fix: negative usec on log line when data type long is 32b
  * mlogc log-line parsing fails due to enhanced timestamp
  * Allow no-key, single-value JSON body
  * Set SecStatusEngine Off in modsecurity.conf-recommended
  * Fix memory leak that occurs on JSON parsing error
  * Multipart names/filenames may include single quote if double-
    quote enclosed
  * Add SecRequestBodyJsonDepthLimit to modsecurity.conf-
    recommended
  * IIS: Update dependencies for Windows build as of v2.9.5
  * Support configurable limit on depth of JSON parsing
- fixes CVE-2022-48279 [bsc#1207378], CVE-2023-24021 [bsc#1207379]
* Mon Jul 19 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 2.9.4:
  * Add microsec timestamp resolution to the formatted log timestamp
  * Added missing Geo Countries
  * Store temporaries in the request pool for regexes compiled per-request.
  * Fix other usage of the global pool for request temporaries in re_operators.c
  * Adds a sanity check before use ctl:ruleRemoveTargetById and ctl:ruleRemoveTargetByMsg.
  * Fix the order of error_msg validation
  * When the input filter finishes, check whether we returned data
  * fix: care non-null terminated chunk data
  * Fix for apr_global_mutex_create() crashes with mod_security
  * Fix inet addr handling on 64 bit big endian systems
- Run spec-cleaner
- Remove if/else for older version of SUSE distribution
* Tue Feb 23 2021 pgajdos@suse.com
- version update to 2.9.3
  * Enable optimization for large stream input by default on IIS
  [Issue #1299 - @victorhora, @zimmerle]
  * Allow 0 length JSON requests.
  [Issue #1822 - @allanbomsft, @zimmerle, @victorhora, @marcstern]
  * Include unanmed JSON values in unnamed ARGS
  [Issue #1577, #1576 - @marcstern, @victorhora, @zimmerle]
  * Fix buffer size for utf8toUnicode transformation
  [Issue #1208 - @katef, @victorhora]
  * Fix sanitizing JSON request bodies in native audit log format
  [p0pr0ck5, @victorhora]
  * IIS: Update Wix installer to bundle a supported CRS version (3.0)
  [@victorhora, @zimmerle]
  * IIS: Update dependencies for Windows build
  [Issue #1848 - @victorhora, @hsluoyz]
  * IIS: Set SecStreamInBodyInspection by default on IIS builds (#1299)
  [Issue #1299 - @victorhora]
  * IIS: Update modsecurity.conf
  [Issue #788 - @victorhora, @brianclark]
  * Add sanity check for a couple malloc() and make code more resilient
  [Issue #979 - @dogbert2, @victorhora, @zimmerl]
  * Fix NetBSD build by renaming the hmac function to avoid conflicts
  [Issue #1241 - @victorhora, @joerg, @sevan]
  * IIS: Windows build, fix duplicate YAJL dir in script
  [Issue #1612 - @allanbomsft, @victorhora]
  * IIS: Remove body prebuffering due to no locking in modsecProcessRequest
  [Issue #1917 - @allanbomsft, @victorhora]
  * Fix mpm-itk / mod_ruid2 compatibility
  [Issue #712 - @ju5t , @derhansen, @meatlayer, @victorhora]
  * Code cosmetics: checks if actionset is not null before use it
  [Issue #1556 - @marcstern, @zimmerle, @victorhora]
  * Only generate SecHashKey when SecHashEngine is On
  [Issue #1671 - @dmuey, @monkburger, @zimmerle]
  * Docs: Reformat README to Markdown and update dependencies
  [Issue #1857 - @hsluoyz, @victorhora]
  * IIS: no lock on ProcessRequest. No reload of config.
  [Issue #1826 - @allanbomsft]
  * IIS: buffer request body before taking lock
  [Issue #1651 - @allanbomsft]
  * good practices: Initialize variables before use it
  [Issue #1889 - Marc Stern]
  * Let body parsers observe SecRequestBodyNoFilesLimit
  [Issue #1613 - @allanbomsft]
  * potential off by one in parse_arguments
  [Issue #1799 - @tinselcity, @zimmerle]
  * Fix utf-8 character encoding conversion
  [Issue #1794 - @tinselcity, @zimmerle]
  * Fix ip tree lookup on netmask content
  [Issue #1793 - @tinselcity, @zimmerle]
  * IIS: set overrideModeDefault to Allow so that individual websites can
  add <ModSecurity ...> to their web.config file
  [Issue #1781 - @default-kramer]
  * modsecurity.conf-recommended: Fix spelling
  [Issue #1721 - @padraigdoran]
  * build: fix when multiple lines for curl version
  [Issue #1771 - @Artistan]
  * Fix arabic charset in unicode_mapping file
  [Issue #1619 - @alaa-ahmed-a]
  * Optionally preallocates memory when SecStreamInBodyInspection is on
  [Issue #1366 - @allanbomsft, @zimmerle]
  * Fixed typo in build_yajl.bat
  [Issue #1366 - @allanbomsft]
  * Fixes SecConnWriteStateLimit
  [Issue #1545 - @nicjansma]
  * Added "empy chunk" check
  [Issue #1347, #1446 - @gravagli, @bostrt, @zimmerle]
  * Add capture action to @detectXSS operator
  [Issue #1488, #1482 - @victorhora]
  * Fix for wildcard operator when loading conf files on Nginx / IIS
  [Issue #1486, #1285 - @victorhora and @thierry-f-78]
  * Set of fixies to make windows build workable with the buildbots
  [Commit 94fe3 - @zimmerle]
  * Uses LOG_NO_STOPWATCH instead of DLOG_NO_STOPWATCH
  [Issue #1510 - @marcstern]
  * Adds missing headers
  [Issue #1454 - @devnexen]
- modified patches
  %% modsecurity-fixes.patch (fix crash caused by our patch)
    [bsc#1180830]
- added patches
  + modsecurity-2.9.3-input_filtering_errors.patch
    [bsc#1180830]
* Wed Feb 12 2020 pgajdos@suse.com
- removing %%apache_test_* macros, do not test module just by
  loading the module
* Fri Dec 29 2017 jengelh@inai.de
- Trim advertisement and filler wording from descriptions.
* Wed Dec 20 2017 pgajdos@suse.com
- fix build for SLE_11_SP4: BuildRoot and %%deffattr have to be
  present
* Mon Oct  2 2017 kstreitova@suse.com
- update to 2.9.2
  * release notes
    https://github.com/SpiderLabs/ModSecurity/releases/tag/v2.9.2
  * refresh apache2-mod_security2-no_rpath.diff
  * remove apache2-mod_security2-lua-5.3.patch that was applied
    upstream
- remove outdated html pages and diagram (they can be accessed
  online at https://github.com/SpiderLabs/ModSecurity/wiki)
  * Reference-Manual.html.bz2
  * ModSecurity-Frequently-Asked-Questions-FAQ.html.bz2
  * modsecurity_diagram_apache_request_cycle.jpg
- don't pack the whole doc directory as it contains also Makefiles
  or doxygen configuration files
- disable mlogc as we don't pack it and it also can't be built for
  curl <=7.34
- add basic and regression test suite (but disabled for now)
  * add apache2-mod_security2_tests_conf.patch for apache2
    configuration file used for tests that was trying to load
    mpm_worker_module (it's static for our apache2 package)
  * add "BuildRequires: perl-libwww-perl" needed for the test suite
* Wed Jun 21 2017 dimstar@opensuse.org
- Update modsecurity-fixes.patch: additionally include netdb.h in
  order to have gethostbyname defined.
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
* Wed Jul 29 2015 pgajdos@suse.com
- fix build for lua 5.3
  + apache2-mod_security2-lua-5.3.patch
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Mon Mar  2 2015 tchvatal@suse.com
- Remove useless comment lines/whitespace
* Tue Feb 24 2015 crrodriguez@opensuse.org
- spec, build: Respect optflags
- spec: buildrequire pkgconfig
- modsecurity-fixes.patch: mod_security fails at:
  * building with optflags enabled due to undefined behaviour
    and implicit declarations.
  * It abuses it apr_allocator api, creating one allocator
    per request and then destroying it, flooding the system
    with mmap() , munmap requests, this is particularly nasty
    with threaded mpms. it should instead use the allocator
    from the request pool.
* Sat Feb 14 2015 thomas.worm@sicsec.de
- Raised to version 2.9.0
- Updated patch: apache2-mod_security2-no_rpath.diff
  (adapted lines)
* Mon Nov  3 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Wed Aug 27 2014 draht@suse.de
- Portability: provide /etc/apache2/mod_security2.d/empty.conf
  to avoid a non-match of the file-glob in the Include statement
  from /etc/apache2/conf.d/mod_security2.conf . This restores
  the Include back from the IncludeOptional, which is not portable.
- Source URL set to (expanded)
  https://www.modsecurity.org/tarball/2.8.0/modsecurity-2.8.0.tar.gz
* Mon Aug 25 2014 thomas.worm@sicsec.de
- Fixed spec file to work with older distribution versions.
  Before openSuSE 13.1 aclocal doesn't work, instead autoreconf
  has to be called.
* Mon Jul  7 2014 draht@suse.de
- last changelog does not say that
  apache2-mod_security2-libtool-fix.diff was obsoleted.
* Mon Jun 16 2014 draht@suse.de
- BuildRequires: libtool missing
* Mon Jun 16 2014 draht@suse.de
- apache2-mod_security2-libtool-fix.diff: initialize libtool.
* Mon Jun 16 2014 draht@suse.de
- apache2-mod_security2-no_rpath.diff: avoid the usage of -rpath
  in autoconf m4 macros. Obsoletes patch
  modsecurity-apache_2.8.0-build_fix_pcre.diff
- use automake for build, add autoconf and automake to
  BuildRequires:. This fix is combined with [bnc#876878].
- turn on --enable-htaccess-config
- use %%{?_smp_mflags} for build
* Thu Jun 12 2014 draht@suse.de
- OWASP rule set. [bnc#876878]
  new in 2.8.0 (more complete changelog to add to last changelog):
  * Connection limits (SecConnReadStateLimit/SecConnWriteStateLimit)
    now support white and suspicious list
  * New variables: FULL_REQUEST and FULL_REQUEST_LENGTH
  * GPLv2 replaced by Apache License v2
  * rules are not part of the source tarball any longer, but
    maintaned upstream externally, and included in this package.
  * documentation was externalized to a wiki. Package contains
    the FAQ and the reference manual in html form.
  * renamed the term "Encryption" in directives that actually refer
    to hashes. See CHANGES file for more details.
  * byte conversion issues on s390x when logging fixed.
  * many small issues fixed that were discovered by a Coverity scanner
  * updated reference manual
  * wrong time calculation when logging for some timezones fixed.
  * replaced time-measuring mechanism with finer granularity for
    measured request/answer phases. (Stopwatch remains for compat.)
  * cookie parser memory leak fix
  * parsing of quoted strings in multipart Content-Disposition
    headers fixed.
* Thu May  1 2014 thomas.worm@sicsec.de
- Raised to version 2.8.0.
- updated patches:
  * modsecurity-apache_2.8.0-build_fix_pcre.diff
  - > modsecurity-apache_2.7.7-build_fix_pcre.diff
* Sat Jan 25 2014 thomas.worm@sicsec.de
- Raised to version 2.7.7.
  - modified patches:
  * modsecurity-apache_2.7.5-build_fix_pcre.diff,
    renamed to modsecurity-apache_2.7.7-build_fix_pcre.diff.
* Thu Jan 23 2014 aj@ajaissle.de
- Use correct source Url
* Fri Aug  2 2013 draht@suse.de
- complete overhaul of this package, with update to 2.7.5.
- ruleset update to 2.2.8-0-g0f07cbb.
- new configuration framework private to mod_security2:
  /etc/apache2/conf.d/mod_security2.conf loads
  /usr/share/apache2-mod_security2/rules/modsecurity_crs_10_setup.conf,
  then /etc/apache2/mod_security2.d/*.conf , as set up based on
  advice in /etc/apache2/conf.d/mod_security2.conf
  Your configuration starting point is
  /etc/apache2/conf.d/mod_security2.conf
- !!! Please note that mod_unique_id is needed for mod_security2 to run!
- modsecurity-apache_2.7.5-build_fix_pcre.diff changes erroneaous
  linker parameter, preventing rpath in shared object.
- fixes contained for the following bugs:
  * CVE-2009-5031, CVE-2012-2751 [bnc#768293] request parameter handling
  * [bnc#768293] multi-part bypass, minor threat
  * CVE-2013-1915 [bnc#813190] XML external entity vulnerability
  * CVE-2012-4528 [bnc#789393] rule bypass
  * CVE-2013-2765 [bnc#822664] null pointer dereference crash
- new from 2.5.9 to 2.7.5, only major changes:
  * GPLv2 replaced by Apache License v2
  * rules are not part of the source tarball any longer, but
    maintaned upstream externally, and included in this package.
  * documentation was externalized to a wiki. Package contains
    the FAQ and the reference manual in html form.
  * renamed the term "Encryption" in directives that actually refer
    to hashes. See CHANGES file for more details.
  * new directive SecXmlExternalEntity, default off
  * byte conversion issues on s390x when logging fixed.
  * many small issues fixed that were discovered by a Coverity scanner
  * updated reference manual
  * wrong time calculation when logging for some timezones fixed.
  * replaced time-measuring mechanism with finer granularity for
    measured request/answer phases. (Stopwatch remains for compat.)
  * cookie parser memory leak fix
  * parsing of quoted strings in multipart Content-Disposition
    headers fixed.
  * SDBM deadlock fix
  * @rsub memory leak fix
  * cookie separator code improvements
  * build failure fixes
  * compile time option --enable-htaccess-config (set)
* Mon Aug 27 2012 cfarrell@suse.com
- license update: Apache-2.0 and GPL-2.0
  Many of the files in the rules/ subdirectory are GPL-2.0 licensed
* Mon Aug  6 2012 crrodriguez@opensuse.org
- Update to version 2.6.7, fixes build in apache 2.4
- Update spec file macros.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jul  6 2011 draht@suse.de
- update to version 2.6.1-rc1 for submission to SLE11-SP2 (fate#309433):
  - SecUnicodeCodePage and SecUnicodeMapFile directives added
  - fixed bug: SecRequestBodyLimit was truncating the real request
    body
  additional fixes from 2.6.0:
  - buffering filter problems fixed
  - memory leak fix when using MATCHED_VAR_NAMES
  - SecWriteStateLimit added against slow DoS
  additional fixes from 2.6.0 release candidates:
  - optimizations
  - bug in logging code fixed
  - cleanup
  - google safe browsing support
* Thu May 14 2009 mrueckert@suse.de
- update to version 2.5.9
  - Fixed parsing multipart content with a missing part header name
    which would crash Apache.  Discovered by "Internet Security
    Auditors" (isecauditors.com).
  - Added ability to specify the config script directly using
  - -with-apr and --with-apu.
  - Added macro expansion for append/prepend action.
  - Fixed race condition in concurrent updates of persistent
    counters.  Updates are now atomic.
  - Cleaned up build, adding an option for verbose configure output
    and making the mlogc build more portable.
- additional changes from 2.5.8
  - Fixed PDF XSS issue where a non-GET request for a PDF file
    would crash the Apache httpd process.  Discovered by Steve
    Grubb at Red Hat.
  - Removed an invalid "Internal error: Issuing "%%s" for
    unspecified error." message that was logged when denying with
    nolog/noauditlog set and causing the request to be audited.
- additional changes from 2.5.7
  - Fixed XML DTD/Schema validation which will now fail after
    request body processing errors, even if the XML parser returns
    a document tree.
  - Added ctl:forceRequestBodyVariable=on|off which, when enabled,
    will force the REQUEST_BODY variable to be set when a request
    body processor is not set.  Previously the REQUEST_BODY target
    was only populated by the URLENCODED request body processor.
  - Integrated mlogc source.
  - Fixed logging the hostname in the error_log which was logging
    the request hostname instead of the Apache resolved hostname.
  - Allow for disabling request body limit checks in phase:1.
  - Added transformations for processing parity for legacy
    protocols ported to HTTP(S): t:parityEven7bit, t:parityOdd7bit,
    t:parityZero7bit
  - Added t:cssDecode transformation to decode CSS escapes.
  - Now log XML parsing/validation warnings and errors to be in the
    debug log at levels 3 and 4, respectivly.
- build and package mlogc
- remove --with-apxs from the configure args as it breaks the build
  configure now finds our apxs2
* Fri Jan 23 2009 skh@suse.de
- fix broken config [bnc#457200]
* Mon Sep 15 2008 skh@suse.de
- update to version 2.5.6
- initial submit to FACTORY
* Mon May 12 2008 jg@internetx.de
-update to 2.1.7
* Sun Feb  3 2008 jg@internetx.de
-update to 2.1.6
* Wed Aug  8 2007 mrueckert@suse.de
- update to 2.1.2
* Mon Apr 16 2007 mrueckert@suse.de
- update to 2.1.1
- switched to perl based patching instead of cmdline params for make
* Fri Sep 22 2006 poeml@suse.de
- fix build (./install was vanished)
